@@ -17,9 +17,24 @@ make_pwfile()
     echo 'cryptuser:tpzv1IkcX9.fE:234:567:Crypt:/home/crypt:/bin/true'
   ) >$CVM_PWFILE_PATH
 }
-testc() { ./cvm-testclient ./cvm-vmailmgr "$@"; }
-testl() { CVM_LOOKUP_SECRET=secret ./cvm-testclient ./cvm-vmailmgr "$@"; }
-testq() { CVM_LOOKUP_SECRET=secret ./cvm-testclient ./cvm-qmail "$@"; }
+
+for base in pwfile qmail vmailmgr; do
+
+cat <<EOF >$tmp/cvm-$base-lookup
+#!/bin/sh
+CVM_LOOKUP_SECRET=secret export CVM_LOOKUP_SECRET
+exec $src/cvm-$base
+EOF
+
+cat <<EOF >$tmp/cvm-$base-nosecret
+#!/bin/bash
+unset CVM_LOOKUP_SECRET
+exec $src/cvm-$base
+EOF
+
+done
+
+chmod +x $tmp/cvm-*
 
 QMAIL_ROOT=$tmp
 export QMAIL_ROOT
@@ -31,6 +46,8 @@ mkdir $tmp/users
   len=`echo $tmp $uid $gid | wc -c`
   printf "+6,%d:!user\0->user\0000$uid\0000$gid\0000$tmp\0\0\n" $(($len+6))
   printf "+6,%d:!user-->user\0000$uid\0000$gid\0000$tmp\0-\0\n" $(($len+7))
+  printf "+7,%d:!alias\0->alias\0000$uid\0000$gid\0000$tmp/alias\0\0\n" $((len+13))
+  printf "+7,%d:!alias-->alias\0000$uid\0000$gid\0000$tmp/alias\0-\0\n" $((len+14))
   printf "+1,%d:!->alias\0000$uid\0000$gid\0000$tmp/alias\0-\0\n" $((len+14))
   echo
 ) | cdbmake $tmp/users/cdb $tmp/users/tmp
@@ -38,22 +55,36 @@ mkdir $tmp/users
 mkdir $tmp/control
 echo local.dom >$tmp/control/locals
 echo test.tld:user >$tmp/control/virtualdomains
+echo noathost:user >>$tmp/control/virtualdomains
+echo noathost >$tmp/control/envnoathost
 mkdir $tmp/alias
 echo \# >$tmp/.qmail-wild-default
 echo \# >$tmp/.qmail-addr
+echo \# >$tmp/.qmail-dot:addr
 echo \# >$tmp/alias/.qmail-alias
 echo \# >$tmp/alias/.qmail-awild-default
+echo \# >$tmp/alias/.qmail-adot:addr
 
 (
   printf '+4,69:virt->\x2\x8\x1\0$1$aSoIrl/J$TmAwoxKzrPJ0IaW5UvX4A0\0./virt\0\0\0-\0-\0-\0-\00001016731358\0-\0\n'
   echo
 ) | cdbmake $tmp/passwd.cdb $tmp/passwd.tmp
 
+sasltest() {
+  make_pwfile
+  env \
+  CVM_SASL_PLAIN=$src/cvm-pwfile \
+  PROTO=TCP \
+  TCPLOCALHOST=localhost \
+  $src/sasl-auth-test "$@"
+  rm -f $CVM_PWFILE_PATH
+}
+
 run_compare_test() {
   local name=$1
   shift
   sed -e "s:@SOURCE@:$src:g"   	-e "s:@TMPDIR@:$tmp:g"   	-e "s:@UID@:$_UID:" 	-e "s:@GID@:$_GID:" 	>$tmp/expected
-  ( runtest "$@" ) 2>&1 >$tmp/actual-raw
+  ( runtest "$@" 2>&1 ) 2>&1 >$tmp/actual-raw
   cat -v $tmp/actual-raw >$tmp/actual
   if ! cmp $tmp/expected $tmp/actual >/dev/null 2>&1
   then
@@ -69,7 +100,7 @@ run_compare_test() {
 
 runtest() {
 make_pwfile
-./cvm-testclient cvm-command:./cvm-pwfile pwfuser '' testpass
+$src/cvm-testclient cvm-command:$src/cvm-pwfile pwfuser '' testpass
 }
 run_compare_test tests/command-prefix  <<END_OF_TEST_RESULTS
 user name:        pwfuser
@@ -89,7 +120,8 @@ END_OF_TEST_RESULTS
 ##### Test tests/vmlookup-upper-domain #####
 
 runtest() {
-testl virt Test.TLD secret
+CVM_LOOKUP_SECRET=secret \
+$src/cvm-testclient $tmp/cvm-vmailmgr-lookup virt Test.TLD
 }
 run_compare_test tests/vmlookup-upper-domain  <<END_OF_TEST_RESULTS
 user name:        virt
@@ -110,7 +142,7 @@ END_OF_TEST_RESULTS
 
 runtest() {
 make_pwfile
-./cvm-testclient ./cvm-pwfile pwfuser '' testpass
+$src/cvm-testclient $src/cvm-pwfile pwfuser '' testpass
 }
 run_compare_test tests/command-no-prefix  <<END_OF_TEST_RESULTS
 user name:        pwfuser
@@ -127,14 +159,93 @@ mailbox path:     (null)
 END_OF_TEST_RESULTS
 
 
+##### Test tests/qmail-lookup-nodomain #####
+
+runtest() {
+CVM_LOOKUP_SECRET=secret \
+$src/cvm-testclient $tmp/cvm-qmail-lookup addr ''
+}
+run_compare_test tests/qmail-lookup-nodomain  <<END_OF_TEST_RESULTS
+user name:        user
+user ID:          500
+group ID:         500
+real name:        (null)
+directory:        /home/bruce/dev/cvm/tests-tmp
+shell:            (null)
+group name:       (null)
+system user name: user
+system directory: /home/bruce/dev/cvm/tests-tmp
+domain:           noathost
+mailbox path:     /home/bruce/dev/cvm/tests-tmp
+END_OF_TEST_RESULTS
+
+
+##### Test tests/chain #####
+
+runtest() {
+CVM_CHAIN0=$src/cvm-pwfile
+CVM_CHAIN1=$src/cvm-vmailmgr
+export CVM_CHAIN0 CVM_CHAIN1
+
+$src/cvm-testclient $src/cvm-chain pwfuser test.tld testpass
+echo
+$src/cvm-testclient $src/cvm-chain virt test.tld pass
+echo
+$src/cvm-testclient $src/cvm-chain notexist test.tld pass
+
+unset CVM_CHAIN0 CVM_CHAIN1
+}
+run_compare_test tests/chain  <<END_OF_TEST_RESULTS
+user name:        pwfuser
+user ID:          123
+group ID:         456
+real name:        Gecos
+directory:        /home/ftp
+shell:            /bin/false
+group name:       (null)
+system user name: (null)
+system directory: (null)
+domain:           (null)
+mailbox path:     (null)
+
+user name:        virt
+user ID:          @UID@
+group ID:         @GID@
+real name:        (null)
+directory:        @TMPDIR@/virt
+shell:            (null)
+group name:       (null)
+system user name: user
+system directory: @TMPDIR@
+domain:           test.tld
+mailbox path:     @TMPDIR@/virt
+
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
+END_OF_TEST_RESULTS
+
+
 ##### Test tests/command-bad-username #####
 
 runtest() {
 make_pwfile
-./cvm-testclient ./cvm-pwfile pxfuser '' testpass
+$src/cvm-testclient $src/cvm-pwfile pxfuser '' testpass
 }
 run_compare_test tests/command-bad-username  <<END_OF_TEST_RESULTS
-Authentication failed, error #100
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
+END_OF_TEST_RESULTS
+
+
+##### Test tests/sasl-eof #####
+
+runtest() {
+sasltest LOGIN </dev/null
+}
+run_compare_test tests/sasl-eof  <<END_OF_TEST_RESULTS
+sasl-auth-test: AUTH LOGIN PLAIN
++ VXNlcm5hbWU6^M
+sasl-auth-test: SASL AUTH LOGIN failed
+sasl-auth-test: Fatal: sasl_auth1 failed: 8
+  535 End of file reached.
 END_OF_TEST_RESULTS
 
 
@@ -143,7 +254,7 @@ END_OF_TEST_RESULTS
 runtest() {
 make_pwfile
 CVM_PWFILE_PWCMP=crypt export CVM_PWFILE_PWCMP
-./cvm-testclient ./cvm-pwfile cryptuser '' testpass
+$src/cvm-testclient $src/cvm-pwfile cryptuser '' testpass
 }
 run_compare_test tests/pwfile-crypt  <<END_OF_TEST_RESULTS
 user name:        cryptuser
@@ -163,7 +274,8 @@ END_OF_TEST_RESULTS
 ##### Test tests/vmlookup-normal #####
 
 runtest() {
-testl virt test.tld secret
+CVM_LOOKUP_SECRET=secret \
+$src/cvm-testclient $tmp/cvm-vmailmgr-lookup virt test.tld
 }
 run_compare_test tests/vmlookup-normal  <<END_OF_TEST_RESULTS
 user name:        virt
@@ -183,7 +295,7 @@ END_OF_TEST_RESULTS
 ##### Test tests/vmailmgr-normal #####
 
 runtest() {
-testc virt test.tld pass
+$src/cvm-testclient $src/cvm-vmailmgr virt test.tld pass
 }
 run_compare_test tests/vmailmgr-normal  <<END_OF_TEST_RESULTS
 user name:        virt
@@ -203,7 +315,8 @@ END_OF_TEST_RESULTS
 ##### Test tests/vmlookup-pass #####
 
 runtest() {
-testl virt test.tld secret
+CVM_LOOKUP_SECRET=secret \
+$src/cvm-testclient $tmp/cvm-vmailmgr-lookup virt test.tld
 }
 run_compare_test tests/vmlookup-pass  <<END_OF_TEST_RESULTS
 user name:        virt
@@ -223,17 +336,17 @@ END_OF_TEST_RESULTS
 ##### Test tests/vmailmgr-upper-pass #####
 
 runtest() {
-testc virt test.tld Pass
+$src/cvm-testclient $src/cvm-vmailmgr virt test.tld Pass
 }
 run_compare_test tests/vmailmgr-upper-pass  <<END_OF_TEST_RESULTS
-Authentication failed, error #100
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
 END_OF_TEST_RESULTS
 
 
 ##### Test tests/vmailmgr-upper-virt #####
 
 runtest() {
-testc Virt test.tld pass
+$src/cvm-testclient $src/cvm-vmailmgr Virt test.tld pass
 }
 run_compare_test tests/vmailmgr-upper-virt  <<END_OF_TEST_RESULTS
 user name:        virt
@@ -253,7 +366,7 @@ END_OF_TEST_RESULTS
 ##### Test tests/vmailmgr-upper-domain #####
 
 runtest() {
-testc virt Test.TLD pass
+$src/cvm-testclient $src/cvm-vmailmgr virt Test.TLD pass
 }
 run_compare_test tests/vmailmgr-upper-domain  <<END_OF_TEST_RESULTS
 user name:        virt
@@ -276,7 +389,8 @@ runtest() {
 local addr="$1"
 local domain="$2"
 
-testq $addr $domain secret
+env CVM_LOOKUP_SECRET=secret \
+$src/cvm-testclient $tmp/cvm-qmail-lookup $addr $domain
 }
 run_compare_test tests/qmail-lookup 'user' 'local.dom' <<END_OF_TEST_RESULTS
 user name:        user
@@ -307,11 +421,11 @@ mailbox path:     @TMPDIR@
 END_OF_TEST_RESULTS
 
 run_compare_test tests/qmail-lookup 'user-addr-x' 'local.dom' <<END_OF_TEST_RESULTS
-Authentication failed, error #100
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
 END_OF_TEST_RESULTS
 
 run_compare_test tests/qmail-lookup 'user-wild' 'local.dom' <<END_OF_TEST_RESULTS
-Authentication failed, error #100
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
 END_OF_TEST_RESULTS
 
 run_compare_test tests/qmail-lookup 'user-wild-x' 'local.dom' <<END_OF_TEST_RESULTS
@@ -357,11 +471,11 @@ mailbox path:     @TMPDIR@/alias
 END_OF_TEST_RESULTS
 
 run_compare_test tests/qmail-lookup 'alias-x' 'local.dom' <<END_OF_TEST_RESULTS
-Authentication failed, error #100
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
 END_OF_TEST_RESULTS
 
 run_compare_test tests/qmail-lookup 'awild' 'local.dom' <<END_OF_TEST_RESULTS
-Authentication failed, error #100
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
 END_OF_TEST_RESULTS
 
 run_compare_test tests/qmail-lookup 'awild-x' 'local.dom' <<END_OF_TEST_RESULTS
@@ -420,11 +534,40 @@ domain:           local.dom
 mailbox path:     @TMPDIR@
 END_OF_TEST_RESULTS
 
+run_compare_test tests/qmail-lookup 'user-dot.addr' 'local.dom' <<END_OF_TEST_RESULTS
+user name:        user
+user ID:          @UID@
+group ID:         @GID@
+real name:        (null)
+directory:        @TMPDIR@
+shell:            (null)
+group name:       (null)
+system user name: user
+system directory: @TMPDIR@
+domain:           local.dom
+mailbox path:     @TMPDIR@
+END_OF_TEST_RESULTS
+
+run_compare_test tests/qmail-lookup 'adot.addr' 'local.dom' <<END_OF_TEST_RESULTS
+user name:        alias
+user ID:          @UID@
+group ID:         @GID@
+real name:        (null)
+directory:        @TMPDIR@/alias
+shell:            (null)
+group name:       (null)
+system user name: alias
+system directory: @TMPDIR@/alias
+domain:           local.dom
+mailbox path:     @TMPDIR@/alias
+END_OF_TEST_RESULTS
+
 
 ##### Test tests/vmlookup-upper-virt #####
 
 runtest() {
-testl Virt test.tld secret
+CVM_LOOKUP_SECRET=secret \
+$src/cvm-testclient $tmp/cvm-vmailmgr-lookup Virt test.tld
 }
 run_compare_test tests/vmlookup-upper-virt  <<END_OF_TEST_RESULTS
 user name:        virt
@@ -447,9 +590,21 @@ runtest() {
 local secret="$1"
 
 make_pwfile
-env CVM_LOOKUP_SECRET=$secret ./cvm-testclient ./cvm-pwfile pwfuser ''
-env CVM_LOOKUP_SECRET=$secret ./cvm-testclient ./cvm-pwfile pwfuser '' ''
-env CVM_LOOKUP_SECRET=$secret ./cvm-testclient ./cvm-pwfile pwfuser '' 'secret'
+cat <<EOF >$tmp/cvmlookup
+#!/bin/sh
+CVM_LOOKUP_SECRET=$secret
+export CVM_LOOKUP_SECRET
+exec $src/cvm-pwfile
+EOF
+chmod +x $tmp/cvmlookup
+
+$src/cvm-testclient $tmp/cvmlookup pwfuser ''
+env CVM_LOOKUP_SECRET='' \
+$src/cvm-testclient $tmp/cvmlookup pwfuser ''
+env CVM_LOOKUP_SECRET=$secret \
+$src/cvm-testclient $tmp/cvmlookup pwfuser ''
+
+rm -f $tmp/cvmlookup
 }
 run_compare_test tests/lookup '' <<END_OF_TEST_RESULTS
 user name:        pwfuser
@@ -463,13 +618,33 @@ system user name: (null)
 system directory: (null)
 domain:           (null)
 mailbox path:     (null)
-Authentication failed, error #2
-Authentication failed, error #2
+user name:        pwfuser
+user ID:          123
+group ID:         456
+real name:        Gecos
+directory:        /home/ftp
+shell:            /bin/false
+group name:       (null)
+system user name: (null)
+system directory: (null)
+domain:           (null)
+mailbox path:     (null)
+user name:        pwfuser
+user ID:          123
+group ID:         456
+real name:        Gecos
+directory:        /home/ftp
+shell:            /bin/false
+group name:       (null)
+system user name: (null)
+system directory: (null)
+domain:           (null)
+mailbox path:     (null)
 END_OF_TEST_RESULTS
 
 run_compare_test tests/lookup 'secret' <<END_OF_TEST_RESULTS
-Authentication failed, error #2
-Authentication failed, error #7
+cvm-testclient: Fatal: Authentication failed, error #7 (Credential missing in data from module)
+cvm-testclient: Fatal: Authentication failed, error #7 (Credential missing in data from module)
 user name:        pwfuser
 user ID:          123
 group ID:         456
@@ -487,10 +662,10 @@ END_OF_TEST_RESULTS
 ##### Test tests/vmlookup-badpass #####
 
 runtest() {
-testl virt test.tld 'xpass'
+$src/cvm-testclient $src/cvm-vmailmgr virt test.tld 'xpass'
 }
 run_compare_test tests/vmlookup-badpass  <<END_OF_TEST_RESULTS
-Authentication failed, error #7
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
 END_OF_TEST_RESULTS
 
 
@@ -498,7 +673,7 @@ END_OF_TEST_RESULTS
 
 runtest() {
 make_pwfile
-./cvm-testclient ./cvm-pwfile pwfuser '' testpass
+$src/cvm-testclient $src/cvm-pwfile pwfuser '' testpass
 }
 run_compare_test tests/pwfile  <<END_OF_TEST_RESULTS
 user name:        pwfuser
@@ -515,14 +690,168 @@ mailbox path:     (null)
 END_OF_TEST_RESULTS
 
 
+##### Test tests/sasl-login1 #####
+
+runtest() {
+sasltest LOGIN <<EOF
+cHdmdXNlcg==
+dGVzdHBhc3M=
+EOF
+}
+run_compare_test tests/sasl-login1  <<END_OF_TEST_RESULTS
+sasl-auth-test: AUTH LOGIN PLAIN
++ VXNlcm5hbWU6^M
++ UGFzc3dvcmQ6^M
+sasl-auth-test: SASL AUTH LOGIN username=pwfuser
+END_OF_TEST_RESULTS
+
+
+##### Test tests/sasl-login2 #####
+
+runtest() {
+sasltest LOGIN\ cHdmdXNlcg== <<EOF
+dGVzdHBhc3M=
+EOF
+}
+run_compare_test tests/sasl-login2  <<END_OF_TEST_RESULTS
+sasl-auth-test: AUTH LOGIN PLAIN
++ UGFzc3dvcmQ6^M
+sasl-auth-test: SASL AUTH LOGIN username=pwfuser
+END_OF_TEST_RESULTS
+
+
+##### Test tests/sasl-nomech #####
+
+runtest() {
+sasltest BOGUS </dev/null
+}
+run_compare_test tests/sasl-nomech  <<END_OF_TEST_RESULTS
+sasl-auth-test: AUTH LOGIN PLAIN
+sasl-auth-test: SASL AUTH BOGUS failed
+sasl-auth-test: Fatal: sasl_auth1 failed: 2
+  504 Unrecognized authentication mechanism.
+END_OF_TEST_RESULTS
+
+
+##### Test tests/sasl-plain1 #####
+
+runtest() {
+sasltest PLAIN <<EOF
+cHdmdXNlcgBwd2Z1c2VyAHRlc3RwYXNz
+EOF
+}
+run_compare_test tests/sasl-plain1  <<END_OF_TEST_RESULTS
+sasl-auth-test: AUTH LOGIN PLAIN
++ ^M
+sasl-auth-test: SASL AUTH PLAIN username=pwfuser
+END_OF_TEST_RESULTS
+
+
+##### Test tests/sasl-plain2 #####
+
+runtest() {
+sasltest PLAIN\ cHdmdXNlcgBwd2Z1c2VyAHRlc3RwYXNz </dev/null
+}
+run_compare_test tests/sasl-plain2  <<END_OF_TEST_RESULTS
+sasl-auth-test: AUTH LOGIN PLAIN
+sasl-auth-test: SASL AUTH PLAIN username=pwfuser
+END_OF_TEST_RESULTS
+
+
 ##### Test tests/command-bad-password #####
 
 runtest() {
 make_pwfile
-./cvm-testclient ./cvm-pwfile pwfuser '' testpassx
+$src/cvm-testclient $src/cvm-pwfile pwfuser '' testpassx
 }
 run_compare_test tests/command-bad-password  <<END_OF_TEST_RESULTS
-Authentication failed, error #100
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
+END_OF_TEST_RESULTS
+
+
+##### Test tests/sasl-plain-fail #####
+
+runtest() {
+sasltest PLAIN\ cHdmdXNlcgBwd2Z1c2VyAHRlc3RwYXNZ </dev/null
+}
+run_compare_test tests/sasl-plain-fail  <<END_OF_TEST_RESULTS
+sasl-auth-test: AUTH LOGIN PLAIN
+sasl-auth-test: SASL AUTH PLAIN failed
+sasl-auth-test: Fatal: sasl_auth1 failed: 1
+  501 Authentication failed.
+END_OF_TEST_RESULTS
+
+
+##### Test tests/v1lookup #####
+
+runtest() {
+local secret="$1"
+
+make_pwfile
+cat <<EOF >$tmp/cvmlookup
+#!/bin/sh
+CVM_LOOKUP_SECRET=$secret
+export CVM_LOOKUP_SECRET
+exec $src/cvm-pwfile
+EOF
+chmod +x $tmp/cvmlookup
+
+$src/cvm-v1testclient $tmp/cvmlookup pwfuser ''
+$src/cvm-v1testclient $tmp/cvmlookup pwfuser '' ''
+$src/cvm-v1testclient $tmp/cvmlookup pwfuser '' secret
+
+rm -f $tmp/cvmlookup
+}
+run_compare_test tests/v1lookup '' <<END_OF_TEST_RESULTS
+user name:        pwfuser
+user ID:          123
+group ID:         456
+real name:        Gecos
+directory:        /home/ftp
+shell:            /bin/false
+group name:       (null)
+system user name: (null)
+system directory: (null)
+domain:           (null)
+mailbox path:     (null)
+user name:        pwfuser
+user ID:          123
+group ID:         456
+real name:        Gecos
+directory:        /home/ftp
+shell:            /bin/false
+group name:       (null)
+system user name: (null)
+system directory: (null)
+domain:           (null)
+mailbox path:     (null)
+user name:        pwfuser
+user ID:          123
+group ID:         456
+real name:        Gecos
+directory:        /home/ftp
+shell:            /bin/false
+group name:       (null)
+system user name: (null)
+system directory: (null)
+domain:           (null)
+mailbox path:     (null)
+END_OF_TEST_RESULTS
+
+run_compare_test tests/v1lookup 'secret' <<END_OF_TEST_RESULTS
+cvm-v1testclient: Fatal: Authentication failed, error #7 (Credential missing in data from module)
+cvm-v1testclient: Fatal: Authentication failed, error #7 (Credential missing in data from module)
+user name:        pwfuser
+user ID:          123
+group ID:         456
+real name:        Gecos
+directory:        /home/ftp
+shell:            /bin/false
+group name:       (null)
+system user name: (null)
+system directory: (null)
+domain:           (null)
+mailbox path:     (null)
 END_OF_TEST_RESULTS
 
 
@@ -569,7 +898,7 @@ END_OF_TEST_RESULTS
 
 runtest() {
 make_pwfile
-./cvm-testclient ./cvm-pwfile PWFUser '' testpass
+$src/cvm-testclient $src/cvm-pwfile PWFUser '' testpass
 }
 run_compare_test tests/command-case  <<END_OF_TEST_RESULTS
 user name:        pwfuser
@@ -589,7 +918,7 @@ END_OF_TEST_RESULTS
 ##### Test tests/start-pwfile-udp #####
 
 runtest() {
-./cvm-pwfile cvm-udp:127.1.2.3:12345 >$tmp/log &
+$src/cvm-pwfile cvm-udp:127.1.2.3:12345 >$tmp/log &
 echo $! >$tmp/pid
 sleep 1
 cat $tmp/log
@@ -603,12 +932,12 @@ END_OF_TEST_RESULTS
 
 runtest() {
 make_pwfile
-./cvm-testclient cvm-udp:127.1.2.3:12345 pwfuser '' testpaxx
+$src/cvm-testclient cvm-udp:127.1.2.3:12345 pwfuser '' testpaxx
 tail -n 1 $tmp/log
 }
 run_compare_test tests/pwfile-udp-bad-password  <<END_OF_TEST_RESULTS
-Authentication failed, error #100
-- pwfuser@
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
+- pwfuser
 END_OF_TEST_RESULTS
 
 
@@ -616,7 +945,7 @@ END_OF_TEST_RESULTS
 
 runtest() {
 make_pwfile
-./cvm-testclient cvm-udp:127.1.2.3:12345 pwfuser '' testpass
+$src/cvm-testclient cvm-udp:127.1.2.3:12345 pwfuser '' testpass
 tail -n 1 $tmp/log
 }
 run_compare_test tests/pwfile-udp  <<END_OF_TEST_RESULTS
@@ -631,7 +960,30 @@ system user name: (null)
 system directory: (null)
 domain:           (null)
 mailbox path:     (null)
-+ pwfuser@
++ pwfuser
+END_OF_TEST_RESULTS
+
+
+##### Test tests/v1udp #####
+
+runtest() {
+make_pwfile
+$src/cvm-v1testclient cvm-udp:127.1.2.3:12345 pwfuser '' testpass
+tail -n 1 $tmp/log
+}
+run_compare_test tests/v1udp  <<END_OF_TEST_RESULTS
+user name:        pwfuser
+user ID:          123
+group ID:         456
+real name:        Gecos
+directory:        /home/ftp
+shell:            /bin/false
+group name:       (null)
+system user name: (null)
+system directory: (null)
+domain:           (null)
+mailbox path:     (null)
++ pwfuser
 END_OF_TEST_RESULTS
 
 
@@ -647,14 +999,14 @@ rm -f $tmp/log
 }
 run_compare_test tests/stop-pwfile-udp  <<END_OF_TEST_RESULTS
 Stopping.
-4 6 42
+5 8 50
 END_OF_TEST_RESULTS
 
 
 ##### Test tests/start-pwfile-local #####
 
 runtest() {
-./cvm-pwfile cvm-local:$tmp/socket >$tmp/log &
+$src/cvm-pwfile cvm-local:$tmp/socket >$tmp/log &
 echo $! >$tmp/pid
 sleep 1
 cat $tmp/log
@@ -668,12 +1020,12 @@ END_OF_TEST_RESULTS
 
 runtest() {
 make_pwfile
-./cvm-testclient cvm-local:$tmp/socket pwfuser '' testpaxx
+$src/cvm-testclient cvm-local:$tmp/socket pwfuser '' testpaxx
 tail -n 1 $tmp/log
 }
 run_compare_test tests/pwfile-local-bad-password  <<END_OF_TEST_RESULTS
-Authentication failed, error #100
-- pwfuser@
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
+- pwfuser
 END_OF_TEST_RESULTS
 
 
@@ -681,7 +1033,7 @@ END_OF_TEST_RESULTS
 
 runtest() {
 make_pwfile
-./cvm-testclient cvm-local:$tmp/socket pwfuser '' testpass
+$src/cvm-testclient cvm-local:$tmp/socket pwfuser '' testpass
 tail -n 1 $tmp/log
 }
 run_compare_test tests/pwfile-local  <<END_OF_TEST_RESULTS
@@ -696,7 +1048,30 @@ system user name: (null)
 system directory: (null)
 domain:           (null)
 mailbox path:     (null)
-+ pwfuser@
++ pwfuser
+END_OF_TEST_RESULTS
+
+
+##### Test tests/v1local #####
+
+runtest() {
+make_pwfile
+$src/cvm-v1testclient cvm-local:$tmp/socket pwfuser '' testpass
+tail -n 1 $tmp/log
+}
+run_compare_test tests/v1local  <<END_OF_TEST_RESULTS
+user name:        pwfuser
+user ID:          123
+group ID:         456
+real name:        Gecos
+directory:        /home/ftp
+shell:            /bin/false
+group name:       (null)
+system user name: (null)
+system directory: (null)
+domain:           (null)
+mailbox path:     (null)
++ pwfuser
 END_OF_TEST_RESULTS
 
 
@@ -713,7 +1088,7 @@ test -e $tmp/socket || echo Socket was removed.
 }
 run_compare_test tests/stop-pwfile-local  <<END_OF_TEST_RESULTS
 Stopping.
-4 6 42
+5 8 50
 Socket was removed.
 END_OF_TEST_RESULTS
 
